<?php
/**
 * VW Health Coaching Theme Customizer
 *
 * @package VW Health Coaching
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_health_coaching_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_health_coaching_custom_controls' );

function vw_health_coaching_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_health_coaching_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-health-coaching' ),
	    'description' => __( 'Description of what this panel does.', 'vw-health-coaching' ),
	) );

	$wp_customize->add_section( 'vw_health_coaching_left_right', array(
    	'title'      => __( 'General Settings', 'vw-health-coaching' ),
		'priority'   => 30,
		'panel' => 'vw_health_coaching_panel_id'
	) );

	$wp_customize->add_setting('vw_health_coaching_width_option',array(
        'default' => __('Full Width','vw-health-coaching'),
        'sanitize_callback' => 'vw_health_coaching_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Health_Coaching_Image_Radio_Control($wp_customize, 'vw_health_coaching_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-health-coaching'),
        'description' => __('Here you can change the width layout of Website.','vw-health-coaching'),
        'section' => 'vw_health_coaching_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_health_coaching_theme_options',array(
        'default' => __('Right Sidebar','vw-health-coaching'),
        'sanitize_callback' => 'vw_health_coaching_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_health_coaching_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-health-coaching'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-health-coaching'),
        'section' => 'vw_health_coaching_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-health-coaching'),
            'Right Sidebar' => __('Right Sidebar','vw-health-coaching'),
            'One Column' => __('One Column','vw-health-coaching'),
            'Three Columns' => __('Three Columns','vw-health-coaching'),
            'Four Columns' => __('Four Columns','vw-health-coaching'),
            'Grid Layout' => __('Grid Layout','vw-health-coaching')
        ),
	));

	$wp_customize->add_setting('vw_health_coaching_page_layout',array(
        'default' => __('One Column','vw-health-coaching'),
        'sanitize_callback' => 'vw_health_coaching_sanitize_choices'
	));
	$wp_customize->add_control('vw_health_coaching_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-health-coaching'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-health-coaching'),
        'section' => 'vw_health_coaching_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-health-coaching'),
            'Right Sidebar' => __('Right Sidebar','vw-health-coaching'),
            'One Column' => __('One Column','vw-health-coaching')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_health_coaching_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-health-coaching' ),
		'priority'   => 30,
		'panel' => 'vw_health_coaching_panel_id'
	) );

	$wp_customize->add_setting('vw_health_coaching_phone',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_health_coaching_phone',array(
		'label'	=> __('Add Phone no.','vw-health-coaching'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'vw-health-coaching' ),
        ),
		'section'=> 'vw_health_coaching_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_health_coaching_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_health_coaching_email_address',array(
		'label'	=> __('Add Email Address','vw-health-coaching'),
		'input_attrs' => array(
            'placeholder' => __( 'support@example.com', 'vw-health-coaching' ),
        ),
		'section'=> 'vw_health_coaching_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_health_coaching_timing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_health_coaching_timing',array(
		'label'	=> __('Add Timing','vw-health-coaching'),
		'input_attrs' => array(
            'placeholder' => __( 'Mon to Fri 8:00AM - 2:00PM', 'vw-health-coaching' ),
        ),
		'section'=> 'vw_health_coaching_topbar',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'vw_health_coaching_search_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_health_coaching_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Health_Coaching_Toggle_Switch_Custom_Control( $wp_customize, 'vw_health_coaching_search_hide_show', array(
		'label' => esc_html__( 'Show / Hide Search','vw-health-coaching' ),
		'section' => 'vw_health_coaching_topbar'
    )));
    
	//Slider
	$wp_customize->add_section( 'vw_health_coaching_slidersettings' , array(
    	'title'      => __( 'Slider Section', 'vw-health-coaching' ),
		'priority'   => null,
		'panel' => 'vw_health_coaching_panel_id'
	) );

	$wp_customize->add_setting( 'vw_health_coaching_slider_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_health_coaching_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Health_Coaching_Toggle_Switch_Custom_Control( $wp_customize, 'vw_health_coaching_slider_hide_show',array(
			'label' => esc_html__( 'Show / Hide Slider','vw-health-coaching' ),
			'section' => 'vw_health_coaching_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'vw_health_coaching_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_health_coaching_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_health_coaching_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-health-coaching' ),
			'description' => __('Slider image size (1500 x 590)','vw-health-coaching'),
			'section'  => 'vw_health_coaching_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_health_coaching_slider_content_option',array(
        'default' => __('Left','vw-health-coaching'),
        'sanitize_callback' => 'vw_health_coaching_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Health_Coaching_Image_Radio_Control($wp_customize, 'vw_health_coaching_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-health-coaching'),
        'section' => 'vw_health_coaching_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_health_coaching_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_health_coaching_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-health-coaching' ),
		'section'     => 'vw_health_coaching_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_health_coaching_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Services
	$wp_customize->add_section( 'vw_health_coaching_service_section' , array(
    	'title'      => __( 'Services Section', 'vw-health-coaching' ),
		'priority'   => null,
		'panel' => 'vw_health_coaching_panel_id'
	) );

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_health_coaching_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_health_coaching_sanitize_choices',
	));
	$wp_customize->add_control('vw_health_coaching_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display services','vw-health-coaching'),
		'description' => __('Image Size (50 x 45)','vw-health-coaching'),
		'section' => 'vw_health_coaching_service_section',
	));

	//Services excerpt
	$wp_customize->add_setting( 'vw_health_coaching_services_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_health_coaching_services_excerpt_number', array(
		'label'       => esc_html__( 'Services Excerpt length','vw-health-coaching' ),
		'section'     => 'vw_health_coaching_service_section',
		'type'        => 'range',
		'settings'    => 'vw_health_coaching_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_health_coaching_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-health-coaching'),
		'panel' => 'vw_health_coaching_panel_id',
	));	

	$wp_customize->add_setting( 'vw_health_coaching_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_health_coaching_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Health_Coaching_Toggle_Switch_Custom_Control( $wp_customize, 'vw_health_coaching_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-health-coaching' ),
        'section' => 'vw_health_coaching_blog_post'
    )));

    $wp_customize->add_setting( 'vw_health_coaching_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_health_coaching_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Health_Coaching_Toggle_Switch_Custom_Control( $wp_customize, 'vw_health_coaching_toggle_author',array(
		'label' => esc_html__( 'Author','vw-health-coaching' ),
		'section' => 'vw_health_coaching_blog_post'
    )));

    $wp_customize->add_setting( 'vw_health_coaching_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_health_coaching_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Health_Coaching_Toggle_Switch_Custom_Control( $wp_customize, 'vw_health_coaching_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-health-coaching' ),
		'section' => 'vw_health_coaching_blog_post'
    )));

    $wp_customize->add_setting( 'vw_health_coaching_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_health_coaching_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-health-coaching' ),
		'section'     => 'vw_health_coaching_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_health_coaching_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Creation
	$wp_customize->add_section( 'vw_health_coaching_content_section' , array(
    	'title' => __( 'Customize Home Page', 'vw-health-coaching' ),
		'priority' => null,
		'panel' => 'vw_health_coaching_panel_id'
	) );

	$wp_customize->add_setting('vw_health_coaching_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Health_Coaching_Content_Creation( $wp_customize, 'vw_health_coaching_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-health-coaching' ),
		),
		'section' => 'vw_health_coaching_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-health-coaching' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('vw_health_coaching_footer',array(
		'title'	=> __('Footer','vw-health-coaching'),
		'description'=> __('This section will appear in the footer','vw-health-coaching'),
		'panel' => 'vw_health_coaching_panel_id',
	));	
	
	$wp_customize->add_setting('vw_health_coaching_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_health_coaching_footer_text',array(
		'label'	=> __('Copyright Text','vw-health-coaching'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018, .....', 'vw-health-coaching' ),
        ),
		'section'=> 'vw_health_coaching_footer',
		'setting'=> 'vw_health_coaching_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'vw_health_coaching_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_health_coaching_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Health_Coaching_Toggle_Switch_Custom_Control( $wp_customize, 'vw_health_coaching_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-health-coaching' ),
      	'section' => 'vw_health_coaching_footer'
    )));

	$wp_customize->add_setting('vw_health_coaching_scroll_top_alignment',array(
        'default' => __('Right','vw-health-coaching'),
        'sanitize_callback' => 'vw_health_coaching_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Health_Coaching_Image_Radio_Control($wp_customize, 'vw_health_coaching_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-health-coaching'),
        'section' => 'vw_health_coaching_footer',
        'settings' => 'vw_health_coaching_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_health_coaching_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Health_Coaching_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Health_Coaching_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Health_Coaching_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW HEALTH COACHING', 'vw-health-coaching' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-health-coaching' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/health-coaching-wordpress-theme/'),
		)));

		// Register sections.
		$manager->add_section(new VW_Health_Coaching_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-health-coaching' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-health-coaching' ),
			'pro_url'  => admin_url('themes.php?page=vw_health_coaching_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-health-coaching-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-health-coaching-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Health_Coaching_Customize::get_instance();